@@ -32,6 +32,9 @@ AUTHFAILURE_SIGN = 'AuthFailure.Sign'
 # 验证失败。
 AUTHFAILURE_VERIFYERROR = 'AuthFailure.VerifyError'
 
+# Token校验失败。
+AUTHFAILURE_VERIFYTOKENFAILURE = 'AuthFailure.VerifyTokenFailure'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
@@ -296,6 +299,9 @@ FAILEDOPERATION_QUERYRESULTNULL = 'FailedOperation.QueryResultNull'
 # 超出商户单日转账额度。
 FAILEDOPERATION_QUOTAEXCEED = 'FailedOperation.QuotaExceed'
 
+# 退款信息重复。
+FAILEDOPERATION_REFUNDINFODUPLICATE = 'FailedOperation.RefundInfoDuplicate'
+
 # 不可重试退款。
 FAILEDOPERATION_REFUNDNOTRETRIEABLE = 'FailedOperation.RefundNotRetrieable'
 
@@ -413,6 +419,9 @@ INTERNALERROR_UNKOWNERROR = 'InternalError.UnkownError'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 传入参数有误，请检查传入参数是否正确。
+INVALIDPARAMETER_BACKENDCGIERROR = 'InvalidParameter.BackendCgiError'
+
 # 缺少必填参数。
 INVALIDPARAMETER_LACKPARAMETER = 'InvalidParameter.LackParameter'
 
