@@ -380,6 +380,9 @@ OPERATIONDENIED_FLOWSTATUSFORBID = 'OperationDenied.FlowStatusForbid'
 # 禁止此项操作。
 OPERATIONDENIED_FORBID = 'OperationDenied.Forbid'
 
+# 签署人年龄限制无法使用电子签服务。
+OPERATIONDENIED_INVALIDAPPROVERAGE = 'OperationDenied.InvalidApproverAge'
+
 # 资源id超过使用上限限制，请联系客服了解规则，并在修改后重试。
 OPERATIONDENIED_MANYRESOURCEID = 'OperationDenied.ManyResourceId'
 
