@@ -62,12 +62,30 @@ FAILEDOPERATION_CONFINUSED = 'FailedOperation.ConfInUsed'
 # 下发CDN平台失败。
 FAILEDOPERATION_CONFIGCDNFAILED = 'FailedOperation.ConfigCDNFailed'
 
+# Cos bucket 不存在。
+FAILEDOPERATION_COSBUCKETNOTEXIST = 'FailedOperation.CosBucketNotExist'
+
+# 无权限访问 Cos bucket。
+FAILEDOPERATION_COSBUCKETNOTPERMISSION = 'FailedOperation.CosBucketNotPermission'
+
+# Cos 角色不存在。
+FAILEDOPERATION_COSROLENOTEXISTS = 'FailedOperation.CosRoleNotExists'
+
 # 2天内有产生流量，域名处于锁定期间，2天内无流量产生才允许删除域名。
 FAILEDOPERATION_DELETEDOMAININLOCKEDTIME = 'FailedOperation.DeleteDomainInLockedTime'
 
+# 域名已添加。
+FAILEDOPERATION_DOMAINADDED = 'FailedOperation.DomainAdded'
+
 # 配置域名规则失败。
 FAILEDOPERATION_DOMAINGSLBFAIL = 'FailedOperation.DomainGslbFail'
 
+# 域名需要实名认证。
+FAILEDOPERATION_DOMAINNEEDREALNAME = 'FailedOperation.DomainNeedRealName'
+
+# 域名归属待验证。
+FAILEDOPERATION_DOMAINNEEDVERIFYOWNER = 'FailedOperation.DomainNeedVerifyOwner'
+
 # 免费证书数量超出限制。
 FAILEDOPERATION_EXCEEDSFREELIMIT = 'FailedOperation.ExceedsFreeLimit'
 
@@ -110,6 +128,9 @@ FAILEDOPERATION_NOREALNAMEAUTH = 'FailedOperation.NoRealNameAuth'
 # 找不到记录。
 FAILEDOPERATION_NOTFOUND = 'FailedOperation.NotFound'
 
+# 父域名已添加。
+FAILEDOPERATION_PARENTDOMAINADDED = 'FailedOperation.ParentDomainAdded'
+
 # 启动混流失败。
 FAILEDOPERATION_PROCESSMIXERROR = 'FailedOperation.ProcessMixError'
 
@@ -125,6 +146,9 @@ FAILEDOPERATION_SDKNOPACKAGE = 'FailedOperation.SdkNoPackage'
 # 流不存在。
 FAILEDOPERATION_STREAMNOTEXIST = 'FailedOperation.StreamNotExist'
 
+# 子域名已添加。
+FAILEDOPERATION_SUBDOMAINADDED = 'FailedOperation.SubDomainAdded'
+
 # 解绑Tag失败，请尝试手动解绑。
 FAILEDOPERATION_TAGUNBINDERROR = 'FailedOperation.TagUnbindError'
 
@@ -341,6 +365,9 @@ INVALIDPARAMETER_DOMAINISLIMITED = 'InvalidParameter.DomainIsLimited'
 # 域名长度超过限制。
 INVALIDPARAMETER_DOMAINTOOLONG = 'InvalidParameter.DomainTooLong'
 
+# 自适应码率子模板gop值必须存在且相等。
+INVALIDPARAMETER_GOPMUSTEQUALANDEXISTS = 'InvalidParameter.GopMustEqualAndExists'
+
 # 输入数目超出限制。
 INVALIDPARAMETER_INPUTNUMLIMITEXCEEDED = 'InvalidParameter.InputNumLimitExceeded'
 
